betty.extension.webpack.jinja2.filter module - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.webpack.jinja2.filter module

Provide Jinja2 filters to integrate with Webpack.

betty.extension.webpack.jinja2.filter.filter_webpack_entry_point_js(context: Context, entry_point_name: str) → None

  Add a Webpack entry point’s JavaScript files to the current page.

  Parameters:

    - context (`jinja2.runtime.Context`)

    - entry_point_name (`str`)

  Return type:

    `None`